@@ -1,6 +1,6 @@
 //===----------------------------------------------------------------------===//
 //
-// Copyright (c) 2012, 2013, 2014 The University of Utah
+// Copyright (c) 2012, 2013, 2014, 2015 The University of Utah
 // All rights reserved.
 //
 // This file is distributed under the University of Illinois Open Source
@@ -354,7 +354,11 @@ bool PointerLevelRewriteVisitor::VisitBinaryOperator(BinaryOperator *BO)
   }
   else if (Ty->isStructureType() || Ty->isUnionType() || 
            Ty->isIntegerType()) {
-    return ConsumerInstance->RewriteHelper->removeAStarAfter(Lhs);
+    if (const ArraySubscriptExpr *ASE = dyn_cast<ArraySubscriptExpr>(Lhs))
+      return ConsumerInstance->RewriteHelper->removeArraySubscriptExpr(
+               ASE->getIdx());
+    else
+      return ConsumerInstance->RewriteHelper->removeAStarAfter(Lhs);
   }
   return true;
 }
