@@ -1,6 +1,6 @@
 //===----------------------------------------------------------------------===//
 //
-// Copyright (c) 2012, 2013 The University of Utah
+// Copyright (c) 2012, 2013, 2015 The University of Utah
 // All rights reserved.
 //
 // This file is distributed under the University of Illinois Open Source
@@ -742,7 +742,7 @@ bool RemoveNamespace::hasNameConflict(const NamedDecl *ND,
     return false;
 
   DeclarationName Name = ND->getDeclName();
-  DeclContextLookupConstResult Result = ParentCtx->lookup(Name);
+  DeclContext::lookup_const_result Result = ParentCtx->lookup(Name);
   return !Result.empty();
 }
 
