@@ -1,6 +1,6 @@
 //===----------------------------------------------------------------------===//
 //
-// Copyright (c) 2012, 2013, 2014 The University of Utah
+// Copyright (c) 2012, 2013, 2014, 2015 The University of Utah
 // All rights reserved.
 //
 // This file is distributed under the University of Illinois Open Source
@@ -389,7 +389,8 @@ std::string SimpleInliner::getNewTmpName(void)
 void SimpleInliner::createReturnVar(void)
 {
   const Type *FDType = CurrentFD->getReturnType().getTypePtr();
-  const Type *CallExprType = TheCallExpr->getCallReturnType().getTypePtr();
+  const Type *CallExprType =
+    TheCallExpr->getCallReturnType().getTypePtr();
 
   // We don't need tmp var
   if (FDType->isVoidType() && CallExprType->isVoidType()) {
