@@ -1,6 +1,6 @@
 //===----------------------------------------------------------------------===//
 //
-// Copyright (c) 2012, 2013 The University of Utah
+// Copyright (c) 2012, 2013, 2015 The University of Utah
 // All rights reserved.
 //
 // This file is distributed under the University of Illinois Open Source
@@ -94,6 +94,10 @@ bool SimplifyIfCollectionVisitor::VisitFunctionDecl(FunctionDecl *FD)
 //     foo(bar())
 bool SimplifyIfStatementVisitor::VisitIfStmt(IfStmt *IS)
 {
+  if (IS->getLocStart().isMacroID()) {
+    return false;
+  }
+
   ConsumerInstance->ValidInstanceNum++;
   if (ConsumerInstance->ValidInstanceNum == 
       ConsumerInstance->TransformationCounter) {
