@@ -1,6 +1,6 @@
 //===----------------------------------------------------------------------===//
 //
-// Copyright (c) 2012, 2013, 2014 The University of Utah
+// Copyright (c) 2012, 2013, 2014, 2015 The University of Utah
 // All rights reserved.
 //
 // This file is distributed under the University of Illinois Open Source
@@ -769,9 +769,18 @@ const CXXRecordDecl *Transformation::getBaseDeclFromType(const Type *Ty)
   case Type::FunctionProto:
   case Type::FunctionNoProto:
   case Type::SubstTemplateTypeParmPack:
+  case Type::PackExpansion:
   case Type::Builtin: // fall-through
     return NULL;
 
+  case Type::Auto: {
+    const AutoType *AutoTy = dyn_cast<AutoType>(Ty);
+    const Type *AT = AutoTy->getDeducedType().getTypePtrOrNull();
+    if (!AT)
+      return NULL;
+    return getBaseDeclFromType(AT);
+  }
+
   default:
     Base = Ty->getAsCXXRecordDecl();
     TransAssert(Base && "Bad base class type!");
